<?php

namespace Drupal\druhels;

use Drupal\node\Entity\Node;
use Drupal\node\NodeInterface;
use Drupal\node\NodeStorageInterface;
use Drupal\node\NodeViewBuilder;

class NodeHelper {

  /**
   * Return TRUE if current page is a node page.
   */
  public static function isNodePage($node_type = NULL): bool {
    static $current_node_type;

    if ($current_node_type === NULL) {
      if (DrupalHelper::getCurrentRouteName() == 'entity.node.canonical') {
        $current_node_type = self::getCurrentNode()->bundle();
      }
      else {
        $current_node_type = FALSE;
      }
    }

    return $node_type ? ($current_node_type == $node_type) : (bool)$current_node_type;
  }

  /**
   * Return current node in node page.
   */
  public static function getCurrentNode(): ?NodeInterface {
    $node = \Drupal::routeMatch()->getParameter('node');

    if ($node && is_numeric($node)) {
      $node = Node::load($node);
    }

    return $node;
  }

  /**
   * Return current node id in node page.
   */
  public static function getCurrentNodeId(): ?int {
    $node_id = \Drupal::routeMatch()->getRawParameter('node');
    return $node_id ? (int)$node_id : NULL;
  }

  /**
   * Return node build array.
   *
   * @param NodeInterface|integer $node - Node object or nid.
   */
  public static function view($node, $view_mode = 'full'): array {
    if (is_numeric($node)) {
      /** @noinspection All */
      $node = Node::load($node);
    }
    $node_view_builder = \Drupal::entityTypeManager()->getViewBuilder('node'); /** @var NodeViewBuilder $node_view_builder */

    return $node_view_builder->view($node, $view_mode);
  }

  /**
   * Return node storage.
   */
  public static function getNodeStorage(): NodeStorageInterface {
    /** @noinspection All */
    return \Drupal::entityTypeManager()->getStorage('node');
  }

}
